Method: Pod::Generator::Acknowledgements#file_accessors
- Defined in:
- lib/cocoapods/generator/acknowledgements.rb
#file_accessors ⇒ Array<Sandbox::FileAccessor> (readonly)
Returns the list of the file accessors for the specs of the target that needs to generate the acknowledgements.
15 16 17 |
# File 'lib/cocoapods/generator/acknowledgements.rb', line 15 def file_accessors @file_accessors end |